//
//  ToolbarItem.m
//  MakeupMirror
//
//  Created by David Phillip Oster on 3/20/09.
//  Copyright 2009 David Phillip Oster. All rights reserved.
//

#import "ToolbarItem.h"
#import "NSImage+additions.h"


@implementation ToolbarItem

- (void)dealloc {
  [baseImage_ release];
  [baseLabel_ release];
  [super dealloc];
}

- (int)state {
  return state_;
}

- (NSString *)label {
  if (NSToolbarDisplayModeLabelOnly != [[self toolbar] displayMode]) {
    return baseLabel_;
  }
  return [super label];
}

- (void)setLabel:(NSString *)label {
  if (baseLabel_ != label) {
    [baseLabel_ release];
    baseLabel_ = [label copy];
  }
  NSString *mark = @"  ";
  switch (state_) {
  case NSOnState: mark = NSLocalizedString(@"check", @"");  break;
  case NSMixedState: mark = @"-";  break;
  }

  if (baseLabel_) {
    [super setLabel:[NSString stringWithFormat:@"%@ %@", mark, baseLabel_]];
  }
}


- (void)setImage:(NSImage *)image {
  if (nil == baseImage_) {
    [baseImage_ release];
    baseImage_ = [image retain];
  }
  NSImage *compositedImage = baseImage_;
  switch (state_) {
  case NSOnState:
    compositedImage = [baseImage_ stampedWith:[NSImage imageNamed:@"check"]];
    break;
  case NSMixedState:
    {
      NSImage *stamp = [NSImage imageNamed:@"graycheck"];
      compositedImage = [baseImage_ stampedWith:stamp];
    }
    break;
  }
  [super setImage:compositedImage];
}

- (void)setState:(int)state {
  if (state_ != state) {
    state_ = state;
    [self setLabel:baseLabel_];
    [self setImage:baseImage_];
  }
}

@end
